@@ -713,7 +713,7 @@ class HarvestText(EntNetworkMixin, EntRetrieveMixin, ParsingMixin, SentimentMixi
             return sents
         else:
             para = re.sub('([。！？\?!])([^”’])', r"\1\n\2", para)  # 单字符断句符
-            para = re.sub('(\.{6})([^”’])', r"\1\n\2", para)  # 英文省略号
+            para = re.sub('(\.{3,6})([^”’])', r"\1\n\2", para)  # 英文省略号
             para = re.sub('(\…{2})([^”’])', r"\1\n\2", para)  # 中文省略号
             para = re.sub('([。！？\?!][”’])([^，。！？\?])', r'\1\n\2', para)
             # 如果双引号前有终止符，那么双引号才是句子的终点，把分句符\n放到双引号后，注意前面的几句都小心保留了双引号
